@@ -21,6 +21,10 @@
 
 class CControllerTokenUpdate extends CController {
 
+	protected function init(): void {
+		$this->setPostContentType(self::POST_CONTENT_TYPE_JSON);
+	}
+
 	protected function checkInput() {
 		$fields = [
 			'tokenid'       => 'db token.tokenid|required|fatal',
@@ -29,13 +33,10 @@ class CControllerTokenUpdate extends CController {
 			'expires_state' => 'in 0,1|required',
 			'expires_at'    => 'abs_time',
 			'status'        => 'db token.status|required|in '.ZBX_AUTH_TOKEN_ENABLED.','.ZBX_AUTH_TOKEN_DISABLED,
-			'action_src'    => 'fatal|required|in token.edit,user.token.edit',
-			'action_dst'    => 'fatal|required|in token.list,user.token.list,token.view,user.token.view',
+			'admin_mode'    => 'required|in 0,1',
 			'regenerate'    => 'in 1'
 		];
 
-		$validation_result = self::VALIDATION_OK;
-
 		$ret = $this->validateInput($fields);
 
 		if ($ret) {
@@ -52,35 +53,21 @@ class CControllerTokenUpdate extends CController {
 					info($error);
 				}
 
-				if ($validator->isErrorFatal()) {
-					$validation_result = self::VALIDATION_FATAL_ERROR;
+				if ($validator->isErrorFatal() || $validator->isError()) {
+					$ret = false;
 				}
-				elseif ($validator->isError()) {
-					$validation_result = self::VALIDATION_ERROR;
-				}
-
-				$ret = $validation_result == self::VALIDATION_OK;
 			}
 		}
-		else {
-			$validation_result = $this->getValidationError();
-		}
 
 		if (!$ret) {
-			switch ($validation_result) {
-				case self::VALIDATION_ERROR:
-					$location = (new CUrl('zabbix.php'))
-						->setArgument('tokenid', $this->getInput('tokenid'))
-						->setArgument('action', $this->getInput('action_src'));
-					$response = new CControllerResponseRedirect($location);
-					$response->setFormData($this->getInputAll());
-					CMessageHelper::setErrorTitle(_('Cannot update API token'));
-					$this->setResponse($response);
-					break;
-				case self::VALIDATION_FATAL_ERROR:
-					$this->setResponse(new CControllerResponseFatal());
-					break;
-			}
+			$this->setResponse(
+				new CControllerResponseData(['main_block' => json_encode([
+					'error' => [
+						'title' => _('Cannot update API token'),
+						'messages' => array_column(get_and_clear_messages(), 'message')
+					]
+				])])
+			);
 		}
 
 		return $ret;
@@ -94,6 +81,9 @@ class CControllerTokenUpdate extends CController {
 		return $this->checkAccess(CRoleHelper::ACTIONS_MANAGE_API_TOKENS);
 	}
 
+	/**
+	 * @throws Exception
+	 */
 	protected function doAction() {
 		$this->getInputs($token, ['tokenid', 'name', 'description', 'expires_at', 'status']);
 
@@ -111,7 +101,15 @@ class CControllerTokenUpdate extends CController {
 
 		$result = API::Token()->update($token);
 
+		$output = [];
+
 		if ($result) {
+			$output['success']['title'] = _('API token updated');
+
+			if ($messages = get_and_clear_messages()) {
+				$output['success']['messages'] = array_column($messages, 'message');
+			}
+
 			if ($this->hasInput('regenerate')) {
 				['tokenids' => $tokenids] = $result;
 				[['userid' => $userid]] = API::Token()->get([
@@ -120,11 +118,6 @@ class CControllerTokenUpdate extends CController {
 				]);
 				[['token' => $auth_token]] = API::Token()->generate($tokenids);
 
-				$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
-					->setArgumentSID()
-					->setArgument('action', $this->getInput('action_dst'))
-				);
-
 				[$user] = (CWebUser::$data['userid'] != $userid)
 					? API::User()->get([
 						'output' => ['username', 'name', 'surname'],
@@ -132,34 +125,25 @@ class CControllerTokenUpdate extends CController {
 					])
 					: [CWebUser::$data];
 
-				$response->setFormData([
+				$output['data'] = [
 					'name' => $token['name'],
-					'user' => getUserFullname($user),
+					'user_name' => getUserFullname($user),
 					'auth_token' => $auth_token,
 					'expires_at' => $token['expires_at'],
 					'description' => $token['description'],
-					'status' => $token['status']
-				]);
+					'status' => $token['status'],
+					'message' => _('API token updated'),
+					'admin_mode' => $this->getInput('admin_mode')
+				];
 			}
-			else {
-				$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
-					->setArgument('action', $this->getInput('action_dst'))
-					->setArgument('page', CPagerHelper::loadPage($this->getInput('action_dst'), null))
-				);
-				$response->setFormData(['uncheck' => '1']);
-			}
-
-			CMessageHelper::setSuccessTitle(_('API token updated'));
 		}
 		else {
-			$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
-				->setArgument('action', $this->getInput('action_src'))
-				->setArgument('tokenid', $this->getInput('tokenid'))
-			);
-			$response->setFormData($this->getInputAll());
-			CMessageHelper::setErrorTitle(_('Cannot update API token'));
+			$output['error'] = [
+				'title' => _('Cannot update API token'),
+				'messages' => array_column(get_and_clear_messages(), 'message')
+			];
 		}
 
-		$this->setResponse($response);
+		$this->setResponse(new CControllerResponseData(['main_block' => json_encode($output)]));
 	}
 }
